@@ -1,3 +1,18 @@
+# Copyright Contributors to the Rez project
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 import platform
 import sys
 import os
@@ -326,7 +341,7 @@ class LinuxPlatform(_UnixPlatform):
 
         known_ids = set()
 
-        proc_re = re.compile('^processor\s*:\s+[0-9]+\s*$', re.MULTILINE)
+        proc_re = re.compile(r'^processor\s*:\s+[0-9]+\s*$', re.MULTILINE)
         procsplit = proc_re.split(contents)
 
         if len(procsplit) <= 1:
@@ -569,19 +584,3 @@ elif name == "darwin":
     platform_ = OSXPlatform()
 elif name == "windows":
     platform_ = WindowsPlatform()
-
-
-# Copyright 2013-2016 Allan Johns.
-#
-# This library is free software: you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation, either
-# version 3 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library.  If not, see <http://www.gnu.org/licenses/>.
